@@ -1,10 +1,14 @@
 ;;;; A Common Lisp interface for libvoikko
 
 (defpackage #:voikko
-  (:use #:cl #:cffi)
+  (:use #:cl)
   (:export #:instance #:activep #:initialize #:terminate
            #:with-instance #:spell #:suggest #:hyphenate #:version
-           #:set-option #:analyze #:split-word
+           #:insert-hyphens
+           #:set-option #:analyze #:split-word #:list-dictionaries
+           #:list-supported-spelling-languages
+           #:list-supported-hyphenation-languages
+           #:list-supported-grammar-checking-languages
 
            #:error-string
            #:voikko-error #:initialize-error #:internal-error
