@@ -1,25 +1,39 @@
-/* Libvoikko: Library of Finnish language tools
- * Copyright (C) 2009 - 2010 Harri Pitkänen <hatapitk@iki.fi>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/* The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Libvoikko: Library of natural language processing tools.
+ * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+ * Portions created by the Initial Developer are Copyright (C) 2009 - 2010
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *********************************************************************************/
 
 #ifndef VOIKKO_GRAMMAR_TOKEN
 #define VOIKKO_GRAMMAR_TOKEN
 
 #include <stddef.h>
+#include <cstdlib>
+#include <cstring>
+#include <list>
+#include "morphology/Analysis.hpp"
 #include "voikko_enums.h"
 
 namespace libvoikko { namespace grammar {
@@ -58,6 +72,9 @@ class Token {
 		/** True if this word may be the main verb */
 		bool possibleMainVerb;
 		
+		/** True if this word is definitely the main verb */
+		bool isMainVerb;
+		
 		/** True if this word is a verb negative ("en", "älä" jne.) */
 		bool isVerbNegative;
 		
@@ -67,6 +84,9 @@ class Token {
 		/** True if this word is a conjunction */
 		bool isConjunction;
 		
+		/** True if this word may be a conjunction */
+		bool possibleConjunction;
+		
 		/**
 		 * What kind of verb must follow this verb in compound verb check. NONE if
 		 * this word is not (or may not be) a verb.
@@ -87,6 +107,9 @@ class Token {
 		
 		/** Position of this token within paragraph */
 		size_t pos;
+
+		/** List of analyses */
+		std::list<morphology::Analysis *> * analyses;
 };
 
 } }
