@@ -60,15 +60,14 @@ class DictionaryFactory {
 	 * tag.
 	 * @return an initialized dictionary
 	 */
-	static Dictionary load(const std::string & language) throw(DictionaryException);
+	static Dictionary load(const std::string & language);
 	
 	/**
 	 * Load dictionary from given path and default locations. The dictionary must match
 	 * given language tag.
 	 * @return an initialized dictionary
 	 */
-	static Dictionary load(const std::string & language, const std::string & path)
-	       throw(DictionaryException);
+	static Dictionary load(const std::string & language, const std::string & path);
 
 	private:
 	static void addAllVersionVariantsFromPath(const std::string & path, std::map<std::string, Dictionary> & variants);
